export declare function isFunction(value: any): value is (...args: any[]) => any;
export declare function isArray(value: any): value is Array<any>;
export declare function isString(value: any): value is string;
export declare function isBoolean(value: any): value is boolean;
export declare function deepMergeWithArray(dest: any, ...src: any): any;
