import type { CracoConfig, WebpackContext } from '@craco/types';
import type { Configuration as WebpackConfig } from 'webpack';
export declare function mergeWebpackConfig(cracoConfig: CracoConfig, webpackConfig: WebpackConfig, context: WebpackContext): WebpackConfig;
