import type { CracoConfig, WebpackContext } from '@craco/types';
export declare function overrideWebpackDev(cracoConfig: CracoConfig, context: WebpackContext): void;
export declare function overrideWebpackProd(cracoConfig: CracoConfig, context: WebpackContext): void;
