import type { CracoConfig } from '@craco/types';
import type { Configuration as WebpackConfig } from 'webpack';
export declare function overrideTypeScript(cracoConfig: CracoConfig, webpackConfig: WebpackConfig): WebpackConfig;
